@@ -128,6 +128,7 @@ class ChatGPT:
         '''
         Close the browser and display
         '''
+        self.__is_active = False
         if hasattr(self, 'driver'):
             self.logger.debug('Closing browser...')
             self.driver.quit()
@@ -222,6 +223,8 @@ class ChatGPT:
         self.logger.debug('Opening chat page...')
         self.driver.get(f'{chatgpt_chat_url}/{self.__conversation_id}')
         self.__check_blocking_elements()
+
+        self.__is_active = True
         Thread(target=self.__keep_alive, daemon=True).start()
 
     def __ensure_cf(self, retry: int = 3) -> None:
@@ -341,7 +344,7 @@ class ChatGPT:
         Keep the session alive by updating the local storage\n
         Credit to Rawa#8132 in the ChatGPT Hacking Discord server
         '''
-        while True:
+        while self.__is_active:
             self.logger.debug('Updating session...')
             payload = (
                 '{"event":"session","data":{"trigger":"getSession"},"timestamp":%d}'
@@ -354,7 +357,7 @@ class ChatGPT:
                 )
             except Exception as e:
                 self.logger.debug(f'Failed to update session: {str(e)}')
-            time.sleep(60)
+            time.sleep(1)
 
     def __check_blocking_elements(self) -> None:
         '''
@@ -375,7 +378,25 @@ class ChatGPT:
             self.logger.debug('Dismissing alert...')
             self.driver.execute_script('arguments[0].remove()', alerts[0])
 
-    def send_message(self, message: str) -> dict:
+    def __stream_message(self):
+        prev_content = ''
+        while True:
+            result_streaming = self.driver.find_elements(*chatgpt_streaming)
+            responses = self.driver.find_elements(*chatgpt_big_response)
+            if responses:
+                response = responses[-1]
+                if 'text-red' in response.get_attribute('class'):
+                    self.logger.debug('Response is an error')
+                    raise ValueError(response.text)
+            response = self.driver.find_elements(*chatgpt_small_response)[-1]
+            content = response.text
+            if content != prev_content:
+                yield content[len(prev_content) :]
+                prev_content = content
+            if not result_streaming:
+                break
+
+    def send_message(self, message: str, stream: bool = False) -> dict:
         '''
         Send a message to ChatGPT\n
         :param message: Message to send
@@ -400,6 +421,12 @@ class ChatGPT:
         )
         textbox.send_keys(Keys.ENTER)
 
+        if stream:
+            for i in self.__stream_message():
+                print(i, end='')
+                time.sleep(0.1)
+            return print()
+
         self.logger.debug('Waiting for completion...')
         WebDriverWait(self.driver, 120).until_not(
             EC.presence_of_element_located(chatgpt_streaming)
